@@ -132,12 +132,14 @@ sub exit{
     my $self = shift;
     my $code = shift;
     $self->info("客户端已退出");
-    exit(defined $code?$code+0:0);
+    $self->emit("stop");
+    CORE::exit(defined $code?$code+0:0);
 }
 sub stop{
     my $self = shift;
     $self->is_stop(1);
     $self->info("客户端停止运行");
+    $self->emit("stop");
     CORE::exit();
 }
 
