@@ -18,6 +18,7 @@ sub to_json_hash{
             $json->{sender_account} = $self->sender->account;
         }
         elsif($key eq "receiver"){
+            next if $self->type eq 'group_message' and $self->class eq 'send';
             $json->{receiver} = decode_utf8($self->receiver->displayname);
             $json->{receiver_account} = $self->receiver->account;
         }
@@ -92,6 +93,9 @@ sub dump{
             my $member_count = @{$self->{$_}};
             $clone->{$_} = [ "$member_count of Object(${obj_name}::Member)" ];
         }
+        elsif($_ eq 'media_data'){
+            $clone->{$_} = '[binary data not shown]';
+        }
         else{
             $clone->{$_} = $self->{$_};
         }
